@@ -23,14 +23,20 @@ module Rabbit
 
       def draw(canvas, x, y, params={})
         if @doc and canvas.poppler_available?
-          params["width"] ||= @width
-          params["height"] ||= @height
-          canvas.draw_poppler_page(page, x, y, params)
+          default_params = {
+            :width => width,
+            :height => height,
+          }
+          canvas.draw_poppler_page(page, x, y, default_params.merge(params))
         else
           super
         end
       end
 
+      def pixbuf
+        @pixbuf ||= to_pixbuf
+      end
+
       private
       def page
         index = self["page"] || 0
@@ -46,11 +52,6 @@ module Rabbit
         _page
       end
 
-      def ensure_resize(w, h)
-        @original_pixbuf ||= to_pixbuf
-        @pixbuf = @original_pixbuf.scale(w, h)
-      end
-
       def update_size
         @doc = Poppler::Document.new(uri)
         @width, @height = page.size
