@@ -57,11 +57,15 @@ module Rabbit
         end
 
         def create_pango_context
-          widget.create_pango_context
+          context = widget.create_pango_context
+          set_font_resolution(context)
+          context
         end
 
         def create_pango_layout(text)
-          widget.create_pango_layout(text)
+          layout = widget.create_pango_layout(text)
+          set_font_resolution(layout.context)
+          layout
         end
 
         def update_title
