@@ -29,12 +29,12 @@ module Rabbit
           @user_accel_group = Gtk::AccelGroup.new
         end
 
-        def attach_key
-          @window.add_accel_group(@accel_group)
+        def attach_key(window)
+          window.add_accel_group(@accel_group)
         end
 
-        def detach_key
-          @window.remove_accel_group(@accel_group)
+        def detach_key(window)
+          window.remove_accel_group(@accel_group)
         end
 
         def clear_keys
@@ -163,11 +163,11 @@ module Rabbit
 
           keys = Keys::Shift::WHITE_OUT_KEYS
           set_keys(keys, mod) do |group, obj, val, modifier|
-            @canvas.activate("ToggleWhiteOut")
+            @canvas.activate("ToggleWhiteout")
           end
           keys = Keys::Shift::BLACK_OUT_KEYS
           set_keys(keys, mod) do |group, obj, val, modifier|
-            @canvas.activate("ToggleBlackOut")
+            @canvas.activate("ToggleBlackout")
           end
           keys = Keys::Shift::TOGGLE_COMMENT_VIEW_KEYS
           set_keys(keys, mod) do |group, obj, val, modifier|
