@@ -253,6 +253,7 @@ module Rabbit
           x, y = from_screen(x, y)
 
           draw_scaled_pixbuf = params[:draw_scaled_pixbuf]
+          draw_scaled_pixbuf = @draw_scaled_image if draw_scaled_pixbuf.nil?
           width = (params[:width] || pixbuf.width).to_f
           height = (params[:height] || pixbuf.height).to_f
           if draw_scaled_pixbuf and
@@ -265,7 +266,7 @@ module Rabbit
               @context.scale(width / pixbuf.width, height / pixbuf.height)
             end
             @context.set_source_pixbuf(pixbuf, 0, 0)
-            @context.paint
+            @context.paint(params[:alpha])
           end
 
           _draw_reflected_pixbuf(pixbuf, x, y, params[:reflect])
@@ -328,6 +329,10 @@ module Rabbit
           context
         end
 
+        def set_font_resolution(context)
+          context.resolution = @canvas.font_resolution
+        end
+
         private
         def init_engine_color
           @foreground = make_color("black")
