@@ -63,8 +63,6 @@ end
 match(TitleSlide, "*") do |elements|
   elements.horizontal_centering = false
   elements.align = :right
-
-  elements.substitute_newline
 end
 
 match(TitleSlide, Title) do |titles|
@@ -96,5 +94,6 @@ include_theme("slide-logo")
 @icon_images = ["clear-blue-icon.png"]
 include_theme("icon")
 
+@slide_footer_info_left_text ||= canvas.title
 @slide_footer_info_right_text ||= "Powered by Rabbit #{Rabbit::VERSION}"
 include_theme("slide-footer-info")
