@@ -3,11 +3,10 @@
 match(Slide) do |slides|
   slides.each do |slide|
     slide.margin_set(@margin_top, @margin_right, @margin_bottom, @margin_left)
-    slide.headline.hide if slide.hide_title?
   end
 end
 
-match(Slide, HeadLine) do
+match(Slide, HeadLine) do |headlines|
   name = "head-line"
   
   delete_post_draw_proc_by_name(name)
@@ -21,6 +20,15 @@ match(Slide, HeadLine) do
     end
     [x, y, w, h]
   end
+
+  headlines.each do |headline|
+    slide = headline.slide
+    headline.hide if slide.hide_title?
+    color = slide["headline-color"]
+    headline.prop_set("foreground", color) if color
+    shadow_color = slide["headline-shadow-color"]
+    headline["shadow-color"] = shadow_color if shadow_color
+  end
 end
 
 match(Slide, Body) do |bodies|
