@@ -19,6 +19,9 @@ end
 @image_slide_number_margin_right ||= nil
 @image_slide_number_margin_bottom ||= nil
 
+@image_slide_number_draw_parameters ||=
+  {:reflect => {:ratio => 0.5, :alpha => 0.5}}
+
 match(Slide) do |slides|
   slides.delete_post_draw_proc_by_name(proc_name)
   
@@ -77,7 +80,7 @@ match(Slide) do |slides|
         if @image_slide_number_show_text
           props = {
             "flag_type" => @image_slide_number_flag_type,
-            "text" => "%0#{max_text_length}d" % canvas.current_index.to_s,
+            "text" => "%0#{max_text_length}d" % slide.index,
             "text_attributes" => text_attributes,
             "flag_color" => "red",
           }
@@ -87,18 +90,21 @@ match(Slide) do |slides|
           props["flag_color"] = "blue"
           canvas.draw_flag(goal_base_x, base_y, loader.height, props)
         else
-          start_loader.draw(canvas, start_base_x, base_y)
-          goal_loader.draw(canvas, goal_base_x, base_y)
+          start_loader.draw(canvas, start_base_x, base_y,
+                            @image_slide_number_draw_parameters)
+          goal_loader.draw(canvas, goal_base_x, base_y,
+                           @image_slide_number_draw_parameters)
         end
       end
 
       if canvas.slide_size < 3
         ratio = 1
       else
-        ratio = (canvas.current_index - 1.0) / (canvas.slide_size - 2.0)
+        ratio = (slide.index - 1.0) / (canvas.slide_size - 2.0)
       end
       current_base_x = base_x + max_width * ratio
-      loader.draw(canvas, current_base_x, base_y)
+      loader.draw(canvas, current_base_x, base_y,
+                  @image_slide_number_draw_parameters)
     end
     [x, y, w, h]
   end
